@@ -11,13 +11,17 @@
 # See the License for the specific language governing permissions and limitations under the License.
 
 catalogue_base_url <- function() {
-  getOption("bcdata.catalogue_gui_url",
-            default = "https://catalogue.data.gov.bc.ca/")
+  getOption(
+    "bcdata.catalogue_gui_url",
+    default = "https://catalogue.data.gov.bc.ca/"
+  )
 }
 
 catalogue_base_api_url <- function() {
-  getOption("bcdata.catalogue_api_url",
-            default = "https://catalogue.data.gov.bc.ca/api/3")
+  getOption(
+    "bcdata.catalogue_api_url",
+    default = "https://catalogue.data.gov.bc.ca/api/3"
+  )
 }
 
 wfs_base_url <- function(host = bcdc_web_service_host()) {
@@ -32,7 +36,7 @@ bcdc_web_service_host <- function() {
   getOption("bcdata.web_service_host", default = "https://openmaps.gov.bc.ca")
 }
 
-bcdata_user_agent <- function(){
+bcdata_user_agent <- function() {
   "https://github.com/bcgov/bcdata"
 }
 
@@ -56,13 +60,12 @@ make_url <- function(..., trailing_slash = FALSE) {
   url
 }
 
-bcdc_number_wfs_records <- function(query_list, client){
-
+bcdc_number_wfs_records <- function(query_list, client) {
   if (!is.null(query_list$count)) {
     return(query_list$count)
   }
 
-  if(!is.null(query_list$propertyName)){
+  if (!is.null(query_list$propertyName)) {
     query_list$propertyName <- NULL
   }
 
@@ -74,10 +77,9 @@ bcdc_number_wfs_records <- function(query_list, client){
   ## resultType is only returned as XML.
   ## regex to extract the number
   as.numeric(sub(".*numberMatched=\"([0-9]{1,20})\".*", "\\1", txt_max))
-
 }
 
-specify_geom_name <- function(cols_df, CQL_statement){
+specify_geom_name <- function(cols_df, CQL_statement) {
   # Find the geometry field and get the name of the field
   geom_col <- geom_col_name(cols_df)
 
@@ -85,25 +87,21 @@ specify_geom_name <- function(cols_df, CQL_statement){
   dbplyr::sql(glue::glue(CQL_statement, geom_name = geom_col))
 }
 
-bcdc_read_sf <- function(x, ...){
-
-  if(length(x) == 1){
-
+bcdc_read_sf <- function(x, ...) {
+  if (length(x) == 1) {
     return(sf::read_sf(x, stringsAsFactors = FALSE, quiet = TRUE, ...))
-
-  } else{
+  } else {
     # tests that cover this are skipped due to large size
     # nocov start
     ## Parse the Paginated response
     message("Parsing data")
-    sf_responses <- lapply(x, function(x) {sf::read_sf(x, stringsAsFactors = FALSE, quiet = TRUE, ...)})
+    sf_responses <- lapply(x, function(x) {
+      sf::read_sf(x, stringsAsFactors = FALSE, quiet = TRUE, ...)
+    })
 
     do.call(rbind, sf_responses)
     # nocov end
   }
-
-
-
 }
 
 slug_from_url <- function(x) {
@@ -111,7 +109,7 @@ slug_from_url <- function(x) {
   x
 }
 
-formats_supported <- function(){
+formats_supported <- function() {
   c(bcdc_read_functions()[["format"]], "zip")
 }
 
@@ -161,26 +159,27 @@ geom_col_name <- function(x) {
   x[x$remote_col_type == geom_type, , drop = FALSE]$col_name
 }
 
-remove_id_col <- function(x){
-setdiff(x, "id")
+remove_id_col <- function(x) {
+  setdiff(x, "id")
 }
 
 #' @param x a resource_df from formatted record
 #' @noRd
 wfs_available <- function(x) {
-  x$location %in% c("bcgwdatastore", "bcgeographicwarehouse") &
+  x$location %in%
+    c("bcgwdatastore", "bcgeographicwarehouse") &
     x$format == "wms"
 }
 
 #' @param x a resource_df from formatted record
 #' @noRd
 other_format_available <- function(x) {
-  x$ext %in% formats_supported() &
+  x$ext %in%
+    formats_supported() &
     !x$location %in% c("bcgwdatastore", "bcgeographicwarehouse")
 }
 
-wfs_to_r_col_type <- function(col){
-
+wfs_to_r_col_type <- function(col) {
   dplyr::case_when(
     col == "xsd:string" ~ "character",
     col == "xsd:date" ~ "date",
@@ -192,21 +191,20 @@ wfs_to_r_col_type <- function(col){
 }
 
 ##from a record
-formats_from_record <- function(x, trim = TRUE){
-
+formats_from_record <- function(x, trim = TRUE) {
   resource_df <- dplyr::tibble(
-      name = purrr::map_chr(x$resources, "name"),
-      url = purrr::map_chr(x$resources, safe_file_ext),
-      format = purrr::map_chr(x$resources, "format")
-    )
+    name = purrr::map_chr(x$resources, "name"),
+    url = purrr::map_chr(x$resources, safe_file_ext),
+    format = purrr::map_chr(x$resources, "format")
+  )
   x <- formats_from_resource(resource_df)
 
-  if(trim) return(x[x != ""])
+  if (trim) return(x[x != ""])
 
   x
 }
 
-formats_from_resource <- function(x){
+formats_from_resource <- function(x) {
   dplyr::case_when(
     x$format == x$url ~ x$format,
     x$format == "wms" ~ "wms",
@@ -246,8 +244,7 @@ get_record_warn_once <- function(...) {
 }
 
 
-
-clean_wfs <- function(x){
+clean_wfs <- function(x) {
   dplyr::case_when(
     x == "WMS getCapabilities request" ~ "WFS request (Spatial Data)",
     x == "wms" ~ "wfs",
@@ -255,19 +252,26 @@ clean_wfs <- function(x){
   )
 }
 
-read_from_url <- function(resource, ...){
-  if (nrow(resource) > 1) stop("more than one resource specified", call. = FALSE)
+read_from_url <- function(resource, ...) {
+  if (nrow(resource) > 1)
+    stop("more than one resource specified", call. = FALSE)
   file_url <- resource$url
   reported_format <- safe_file_ext(resource)
   if (!reported_format %in% formats_supported()) {
-    stop("Reading ", reported_format, " files is not currently supported in bcdata.")
+    stop(
+      "Reading ",
+      reported_format,
+      " files is not currently supported in bcdata."
+    )
   }
   auth <- grepl("(cat(alogue)?|pub)\\.data\\.gov\\.bc\\.ca", file_url)
   cli <- bcdc_http_client(file_url, auth = auth)
 
   ## Establish where to download file
-  tmp <- tempfile(tmpdir = unique_temp_dir(),
-                  fileext = paste0(".", tools::file_ext(file_url)))
+  tmp <- tempfile(
+    tmpdir = unique_temp_dir(),
+    fileext = paste0(".", tools::file_ext(file_url))
+  )
   on.exit(unlink(tmp))
 
   r <- cli$get(disk = tmp)
@@ -283,23 +287,32 @@ read_from_url <- function(resource, ...){
   # This assumes that the function we are using to read the data takes the
   # data as the first argument - will need revisiting if we find a situation
   # where that's not the case
-  message("Reading the data using the ", fun$fun, " function from the ",
-          fun$package, " package.")
+  message(
+    "Reading the data using the ",
+    fun$fun,
+    " function from the ",
+    fun$package,
+    " package."
+  )
   handle_excel(tmp, ...)
 
-tryCatch(
-  do.call(fun$fun, list(tmp, ...)),
-  error = function(e) {
-    stop("Reading the data set failed with the following error message:\n\n  ", e,
-    "\nThe file can be found here:\n  '",
-    tmp, "'\nif you would like to try to read it manually.\n",
-    call. = FALSE)
-  }
-)
+  tryCatch(
+    do.call(fun$fun, list(tmp, ...)),
+    error = function(e) {
+      stop(
+        "Reading the data set failed with the following error message:\n\n  ",
+        e,
+        "\nThe file can be found here:\n  '",
+        tmp,
+        "'\nif you would like to try to read it manually.\n",
+        call. = FALSE
+      )
+    }
+  )
 }
 
 
-resource_to_tibble <- function(x){
+resource_to_tibble <- function(x) {
   res_df <- dplyr::tibble(
     name = safe_map_chr(x, "name"),
     url = safe_map_chr(x, "url"),
@@ -309,11 +322,13 @@ resource_to_tibble <- function(x){
     package_id = safe_map_chr(x, "package_id"),
     location = simplify_string(safe_map_chr(x, "resource_storage_location"))
   )
-  
-  dplyr::mutate(res_df,
+
+  dplyr::mutate(
+    res_df,
     wfs_available = wfs_available(res_df),
-    bcdata_available = wfs_available | other_format_available(res_df))
-  }
+    bcdata_available = wfs_available | other_format_available(res_df)
+  )
+}
 
 #' @importFrom rlang "%||%"
 safe_map_chr <- function(x, name) {
@@ -355,15 +370,15 @@ handle_zip <- function(x) {
   files <- list_supported_files(dir)
   # check if it's a shapefile
 
-if (length(files) > 1L) {
-  stop(
-    "More than one supported file in zip file. It has been downloaded and ",
-    "extracted to '",
-    dir,
-    "', where you can access its contents manually.",
-    call. = FALSE
-  )
-}
+  if (length(files) > 1L) {
+    stop(
+      "More than one supported file in zip file. It has been downloaded and ",
+      "extracted to '",
+      dir,
+      "', where you can access its contents manually.",
+      call. = FALSE
+    )
+  }
 
   files
 }
@@ -375,10 +390,18 @@ handle_excel <- function(tmp, ...) {
 
   sheets <- readxl::excel_sheets(tmp)
   if (length(sheets) > 1L) {
-    message(paste0("\nThis .", tools::file_ext(tmp), " resource contains the following sheets: \n",
-                   paste0(" '", sheets,"'", collapse = "\n")))
+    message(paste0(
+      "\nThis .",
+      tools::file_ext(tmp),
+      " resource contains the following sheets: \n",
+      paste0(" '", sheets, "'", collapse = "\n")
+    ))
     if (!methods::hasArg("sheet")) {
-      message("Defaulting to the '", sheets[1], "' sheet. See ?bcdc_get_data for examples on how to specify a sheet.\n")
+      message(
+        "Defaulting to the '",
+        sheets[1],
+        "' sheet. See ?bcdc_get_data for examples on how to specify a sheet.\n"
+      )
     }
   }
 }
@@ -399,8 +422,8 @@ list_supported_files <- function(dir) {
     if (!length(list.dirs(dir, recursive = FALSE))) {
       stop("No supported files found", call. = FALSE)
     }
-      files <- list.files(dir, full.names = TRUE, recursive = TRUE)
-      supported <- is_filetype(files, formats_supported())
+    files <- list.files(dir, full.names = TRUE, recursive = TRUE)
+    supported <- is_filetype(files, formats_supported())
   }
 
   files[supported]
@@ -424,24 +447,35 @@ catch_wfs_error <- function(catalogue_response) {
 
     msg <- paste0(
       msg,
-      cli::rule(line = "bar4", line_col = 'red'),"\n",
+      cli::rule(line = "bar4", line_col = 'red'),
+      "\n",
       "Request:",
-      "\n  URL: ", catalogue_response$request$url$url,
-      "\n  POST fields:\n    ", rawToChar(catalogue_response$request$options$postfields),
+      "\n  URL: ",
+      catalogue_response$request$url$url,
+      "\n  POST fields:\n    ",
+      rawToChar(catalogue_response$request$options$postfields),
       "\n"
     )
 
     for (i in seq_along(request_res)) {
       msg <- paste0(
-        msg, "  ", names(request_res)[i], ": ",
-        request_res[i], "\n"
+        msg,
+        "  ",
+        names(request_res)[i],
+        ": ",
+        request_res[i],
+        "\n"
       )
     }
     msg <- paste0(msg, "Response:\n")
     for (i in seq_along(response_res)) {
       msg <- paste0(
-        msg, "  ", names(response_res)[i], ": ",
-        response_res[i], "\n"
+        msg,
+        "  ",
+        names(response_res)[i],
+        ": ",
+        response_res[i],
+        "\n"
       )
     }
   }
