@@ -23,11 +23,13 @@ test_that("bcdc_query_geodata returns an bcdc_promise object for a valid id OR b
   expect_equal(bc_airports, bc_airports2)
 
   # neither character nor bcdc_record
-  expect_error(bcdc_query_geodata(1L),
-               "No bcdc_query_geodata method for an object of class integer")
+  expect_error(
+    bcdc_query_geodata(1L),
+    "No bcdc_query_geodata method for an object of class integer"
+  )
 })
 
-test_that("bcdc_query_geodata returns an object with a query, a cli, the catalogue object, and a df of column names",{
+test_that("bcdc_query_geodata returns an object with a query, a cli, the catalogue object, and a df of column names", {
   skip_if_net_down()
   skip_on_cran()
   bc_airports <- bcdc_query_geodata("bc-airports")
@@ -38,7 +40,7 @@ test_that("bcdc_query_geodata returns an object with a query, a cli, the catalog
 })
 
 
-test_that("bcdc_query_geodata returns an object with bcdc_promise class when using filter",{
+test_that("bcdc_query_geodata returns an object with bcdc_promise class when using filter", {
   skip_on_cran()
   skip_if_net_down()
   bc_eml <- bcdc_query_geodata("bc-environmental-monitoring-locations") %>%
@@ -47,7 +49,7 @@ test_that("bcdc_query_geodata returns an object with bcdc_promise class when usi
 })
 
 
-test_that("bcdc_query_geodata returns an object with bcdc_promise class on record under 10000",{
+test_that("bcdc_query_geodata returns an object with bcdc_promise class on record under 10000", {
   skip_on_cran()
   skip_if_net_down()
   airports <- bcdc_query_geodata("bc-airports")
@@ -57,13 +59,20 @@ test_that("bcdc_query_geodata returns an object with bcdc_promise class on recor
 test_that("bcdc_query_geodata fails when >1 record", {
   skip_if_net_down()
   skip_on_cran()
-  expect_error(bcdc_query_geodata(c("bc-airports", "bc-environmental-monitoring-locations")),
-               "Only one record my be queried at a time")
+  expect_error(
+    bcdc_query_geodata(c(
+      "bc-airports",
+      "bc-environmental-monitoring-locations"
+    )),
+    "Only one record my be queried at a time"
+  )
 })
 
 test_that("bcdc_query_geodata fails when no wfs available", {
   skip_if_net_down()
   skip_on_cran()
-  expect_error(bcdc_query_geodata("dba6c78a-1bc1-4d4f-b75c-96b5b0e7fd30"),
-               "No Web Feature Service resource available")
+  expect_error(
+    bcdc_query_geodata("dba6c78a-1bc1-4d4f-b75c-96b5b0e7fd30"),
+    "No Web Feature Service resource available"
+  )
 })
