@@ -10,13 +10,14 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and limitations under the License.
 
-
-
-
 # Precompile vignettes
 
 precompile <- function(vignette_to_run = NULL) {
-  orig_files <- file.path(list.files(path = "vignettes/", pattern = "*\\.Rmd\\.orig", full.names = TRUE))
+  orig_files <- file.path(list.files(
+    path = "vignettes/",
+    pattern = "*\\.Rmd\\.orig",
+    full.names = TRUE
+  ))
 
   if (!is.null(vignette_to_run)) {
     orig_files <- orig_files[basename(orig_files) %in% vignette_to_run]
@@ -25,13 +26,15 @@ precompile <- function(vignette_to_run = NULL) {
   }
 
   # Convert *.orig to *.Rmd -------------------------------------------------
-  purrr::walk(orig_files, ~knitr::knit(.x, tools::file_path_sans_ext(.x)))
+  purrr::walk(orig_files, ~ knitr::knit(.x, tools::file_path_sans_ext(.x)))
 
   # Move .png files into correct directory so they render -------------------
   images <- file.path(list.files(".", pattern = 'vignette-fig.*\\.png$'))
-  success <- file.copy(from = images,
-                       to = file.path("vignettes", images),
-                       overwrite = TRUE)
+  success <- file.copy(
+    from = images,
+    to = file.path("vignettes", images),
+    overwrite = TRUE
+  )
 
   # Clean up if successful --------------------------------------------------
   if (!all(success)) {
@@ -45,4 +48,4 @@ precompile <- function(vignette_to_run = NULL) {
 precompile()
 
 ## Or just one
-#precompile("bcdata.Rmd.orig")
\ No newline at end of file
+#precompile("bcdata.Rmd.orig")
